import * as React from "react";
import type { BaseProps } from "./~utils.js";
interface RootProps extends BaseProps {
    /**
     * The color scheme to use for all components under the Root.
     */
    colorScheme: "light" | "dark";
    /**
     * Whether to synchronize the color scheme with the parent document (or shadow-root host).
     *
     * This is useful when you don't have explicit control over the color scheme of the host.
     *
     * @default false
     */
    synchronizeColorScheme?: boolean;
    /**
     * The density to use for all components under the Root.
     */
    density: "dense";
    /**
     * An HTML sanitizer function that will be used across all components wherever DOM elements
     * are created from HTML strings.
     *
     * When this prop is not passed, sanitization will be skipped.
     *
     * Example:
     * ```tsx
     * unstable_htmlSanitizer={DOMPurify.sanitize}
     * ```
     */
    unstable_htmlSanitizer?: (html: string) => string;
}
/**
 * Component to be used at the root of your application. It ensures that kiwi styles and fonts are loaded
 * and automatically applied to the current page or the encompassing shadow-root.
 *
 * Make sure to specify the `colorScheme` and `density` props.
 *
 * Example:
 * ```tsx
 * <Root colorScheme="dark" density="dense">
 *   <App />
 * </Root>
 * ```
 */
export declare const Root: React.ForwardRefExoticComponent<RootProps & React.RefAttributes<HTMLElement | HTMLDivElement>>;
export {};
